@@ -24,6 +24,11 @@ sCommand* sCommand_new(sStatment* statment)
     self->mBlocksSize = 4;
     self->mBlocksNum = 0;
 
+    self->mRedirectsFileNames = MALLOC(sizeof(char*)*4);
+    self->mRedirects = MALLOC(sizeof(int)*4);
+    self->mRedirectsSize = 4;
+    self->mRedirectsNum = 0;
+
     memset(self->mMessages, 0, sizeof(char*)*XYZSH_MESSAGES_MAX);
     self->mMessagesNum = 0;
 
@@ -226,6 +231,17 @@ static void sCommand_copy_deeply(sCommand* dest, sCommand* src)
         dest->mBlocks[i] = block_clone_gc(src->mBlocks[i], T_BLOCK, FALSE);
     }
 
+    dest->mRedirectsFileNames = MALLOC(sizeof(char*)*src->mRedirectsSize);
+    for(i=0; i<src->mRedirectsNum; i++) {
+        dest->mRedirectsFileNames[i] = STRDUP(src->mRedirectsFileNames[i]);
+    }
+    dest->mRedirects = MALLOC(sizeof(int)*src->mRedirectsSize);
+    for(i=0; i<src->mRedirectsNum; i++) {
+        dest->mRedirects[i] = src->mRedirects[i];
+    }
+    dest->mRedirectsSize = src->mRedirectsSize;
+    dest->mRedirectsNum = src->mRedirectsNum;
+
 /*
     memcpy(dest->mOptions, src->mOptions, sizeof(option_hash_it)*XYZSH_OPTION_MAX);
     for(i=0; i<XYZSH_OPTION_MAX; i++) {
@@ -298,6 +314,17 @@ static void sCommand_copy_deeply_stack(sCommand* dest, sCommand* src)
         dest->mBlocks[i] = block_clone_stack(src->mBlocks[i], T_BLOCK);
     }
 
+    dest->mRedirectsFileNames = MALLOC(sizeof(char*)*src->mRedirectsSize);
+    for(i=0; i<src->mRedirectsNum; i++) {
+        dest->mRedirectsFileNames[i] = STRDUP(src->mRedirectsFileNames[i]);
+    }
+    dest->mRedirects = MALLOC(sizeof(int)*src->mRedirectsSize);
+    for(i=0; i<src->mRedirectsNum; i++) {
+        dest->mRedirects[i] = src->mRedirects[i];
+    }
+    dest->mRedirectsSize = src->mRedirectsSize;
+    dest->mRedirectsNum = src->mRedirectsNum;
+
 /*
     memcpy(dest->mOptions, src->mOptions, sizeof(option_hash_it)*XYZSH_OPTION_MAX);
 
@@ -346,6 +373,12 @@ void sCommand_delete(sCommand* self)
     }
 
     FREE(self->mBlocks);
+
+    FREE(self->mRedirectsFileNames);
+    for(i=0; i<self->mRedirectsNum; i++) {
+        FREE(self->mRedirectsFileNames[i]);
+    }
+    FREE(self->mRedirects);
 }
 
 void sCommand_view(sCommand* self)
@@ -790,7 +823,7 @@ static BOOL expand_env_to_command(ALLOC char** result, char* str, sCommand* comm
             /// block ///
             else {
                 int rcode;
-                sObject* nextout = FD_NEW_STACK();
+                sObject* nextout = FD_NEW_STACK(kFDKindBuf, 0);
 
                 if(!run(env->mBlock, nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject))
                 {
@@ -800,7 +833,7 @@ static BOOL expand_env_to_command(ALLOC char** result, char* str, sCommand* comm
                     return FALSE;
                 }
 
-                add_str_to_buf(&buf, SFD(nextout).mBuf);
+                add_str_to_buf(&buf, SFD(nextout).fdbuf.mBuf);
             }
         }
         else {
@@ -1325,3 +1358,16 @@ void sCommand_sweep_runtime_info(sCommand* self)
 
     memset(self->mOptions, 0, sizeof(option_hash_it)*XYZSH_OPTION_MAX);
 }
+
+void sCommand_add_redirect_to_command(sCommand* self, MANAGED char* name, int redirect)
+{
+    if(self->mRedirectsNum >= self->mRedirectsSize) {
+        self->mRedirectsSize *= 2;
+        self->mRedirectsFileNames = REALLOC(self->mRedirectsFileNames, sizeof(char*)*self->mRedirectsSize);
+        self->mRedirects = REALLOC(self->mRedirects, sizeof(int)*self->mRedirectsSize);
+    }
+
+    self->mRedirectsFileNames[self->mRedirectsNum] = name;
+    self->mRedirects[self->mRedirectsNum++] = redirect;
+}
+
