@@ -841,6 +841,7 @@ static BOOL read_statment(char**p, sStatment* statment, sObject* block, char* sn
 
         SBLOCK(block).mCompletionFlags &= ~COMPLETION_FLAGS_STATMENT_HEAD;
 
+/*
         /// write ///
         if(command->mArgsNum > 1 && strcmp(command->mArgs[0], "write") == 0) {
             if(statment->mCommandsNum > 1) {
@@ -879,8 +880,10 @@ static BOOL read_statment(char**p, sStatment* statment, sObject* block, char* sn
                 return FALSE;
             }
         }
+        else
+*/
         /// There is no argument, so delete last command in block ///
-        else if(command->mArgsNum == 0)
+        if(command->mArgsNum == 0)
         {
             if(command->mMessagesNum > 0) {
                 err_msg("require command name", sname, *sline, NULL);
