@@ -64,7 +64,6 @@ int sTestObj_markfun(sObject* self)
 
 void sTestObj_freefun(void* self)
 {
-puts("sTestObj freed");
     sTestObj* obj = self;
     FREE(obj->mData);
     FREE(obj);
@@ -524,3 +523,9 @@ char* xstrncat(char* des, char* str, int size)
     des[size-1] = 0;
     return strncat(des, str, size-1);
 }
+
+int xyzsh_job_num()
+{
+    return vector_size(gJobs);
+}
+
